@@ -21,18 +21,15 @@ import basicMonster
 _moduleLogger = logging.getLogger(__name__)
 
 
-global levelselect
 # Warn if soundrr or fonts are disabled
 if not pygame.font:
-	print 'Warning, fonts disabled'
+	_moduleLogger.info('Warning, fonts disabled')
 if not pygame.mixer:
-	print 'Warning, sound disabled'
+	_moduleLogger.info('Warning, sound disabled')
 
 
 BLOCK_SIZE = 32
-fps = 30
-clock = pygame.time.Clock()
-levelselect = 0
+FRAMES_PER_SECOND = 30
 DATA_FOLDER = os.path.join(os.path.dirname(__file__), "data")
 
 
@@ -43,15 +40,10 @@ class nomMain(object):
 		pygame.init()
 		pygame.mouse.set_visible(False)
 		pygame.mixer.init()
+		self._clock = pygame.time.Clock()
 		DATA_FOLDER = os.path.join(os.path.dirname(__file__), "data")
 		self.level1 = None
-		#global gameMusic
-		#global gameSound
-		#global player_speed
-		#global enemy_speed
-		#self.greenScore = 0
-		#self.purpleScore = 0
-		#if config.gameMusic == 1:
+		#if config.gameMusic:
 		#	pygame.mixer.music.load('data/sounds/music1.wav')
 		#	pygame.mixer.music.play(-1, 0)
 		self.width = width
@@ -59,11 +51,10 @@ class nomMain(object):
 		self.screen = pygame.display.set_mode((self.width, self.height), pygame.locals.FULLSCREEN)
 
 	def MainLoop(self):
-		global levelselect
 		self.dead = 0
 		if config.deathCount == 0:
-			config.currentLvl = levelselect
-			levelselect = 100
+			config.currentLvl = config.levelselect
+			config.levelselect = 100
 			config.deathCount = 3
 			self.dead = 1
 			self.ShowScores()
@@ -77,8 +68,8 @@ class nomMain(object):
 		self.block_sprites.draw(self.screen)
 		self.block_sprites.draw(self.background)
 		pygame.display.flip()
-		#if config.gameMusic == 1:
-		#	if levelselect == 7:
+		#if config.gameMusic:
+		#	if config.levelselect == 7:
 		#		pygame.mixer.music.stop()
 		#		pygame.mixer.music.load('data/sounds/mario.wav')
 		#		pygame.mixer.music.play(-1, 0)
@@ -87,13 +78,13 @@ class nomMain(object):
 		killSound = self.level1.killSound
 
 		while True:
-			if levelselect == 100:
+			if config.levelselect == 100:
 				if self.greenMan.pellets == 1:
 					pygame.quit()
 					loadGui = sys.executable
 					os.execl(loadGui, loadGui, * sys.argv)
 				elif self.greenMan.supers == 1:
-					levelselect = config.currentLvl
+					config.levelselect = config.currentLvl
 					config.greenScore = 0
 					config.purpleScore = 0
 					config.greenHits = 0
@@ -103,8 +94,8 @@ class nomMain(object):
 					config.deathCount = 3
 					pygame.quit()
 					nomMain().MainLoop()
-			tick_time = clock.tick(fps)
-			#pygame.display.set_caption("Omnom. FPS: %.2f" % (clock.get_fps()))
+			tick_time = self._clock.tick(FRAMES_PER_SECOND)
+			#pygame.display.set_caption("Omnom. FPS: %.2f" % (self._clock.get_fps()))
 			#2 player here
 			if config.players == 2:
 				while self.greenMan.pellets+self.purpleMan.pellets == self.total:
@@ -112,9 +103,9 @@ class nomMain(object):
 					config.purpleScore = config.purpleScore+self.purpleMan.pellets
 					#config.greenHits = config.greenHits+self.greenMan.hits
 					#config.purpleHits = config.purpleHits+self.purpleMan.hits
-					levelselect = levelselect+1
-					if levelselect == 16:
-						#levelselect = 1
+					config.levelselect += 1
+					if config.levelselect == 16:
+						#config.levelselect = 1
 						#speedBoost = 2
 						#config.enemy_speed = config.player_speed
 						self.ShowScores()
@@ -128,10 +119,10 @@ class nomMain(object):
 				#while self.greenMan.pellets == self.level1.pelletcount:
 				while self.greenMan.pellets == self.total:
 					config.greenScore = config.greenScore+self.greenMan.pellets
-					levelselect = levelselect+1
-					if levelselect == 16:
+					config.levelselect += 1
+					if config.levelselect == 16:
 						#pygame.quit()
-						#levelselect = 1
+						#config.levelselect = 1
 						#speedBoost = 2
 						#config.enemy_speed = config.player_speed
 						self.ShowScores()
@@ -155,10 +146,10 @@ class nomMain(object):
 					or (event.key == pygame.locals.K_UP)
 					or (event.key == pygame.locals.K_DOWN)):
 						self.greenMan.MoveKeyDown(event.key)
-					if ((event.key == pygame.locals.K_x)
-					or (event.key == pygame.locals.K_a)
+					if ((event.key == pygame.locals.K_f)
 					or (event.key == pygame.locals.K_s)
-					or (event.key == pygame.locals.K_z)):
+					or (event.key == pygame.locals.K_e)
+					or (event.key == pygame.locals.K_c)):
 						if config.players == 2:
 							self.purpleMan.MoveKeyDown(event.key)
 					if event.key == pygame.locals.K_p:
@@ -167,19 +158,16 @@ class nomMain(object):
 						pygame.quit()
 						loadGui = sys.executable
 						os.execl(loadGui, loadGui, * sys.argv)
-					if event.key == pygame.locals.K_SPACE:
-						pygame.quit()
-						nomMain().MainLoop()
 				elif event.type == pygame.locals.KEYUP:
 					if ((event.key == pygame.locals.K_RIGHT)
 					or (event.key == pygame.locals.K_LEFT)
 					or (event.key == pygame.locals.K_UP)
 					or (event.key == pygame.locals.K_DOWN)):
 						self.greenMan.MoveKeyUp(event.key)
-					if ((event.key == pygame.locals.K_x)
-					or (event.key == pygame.locals.K_a)
+					if ((event.key == pygame.locals.K_f)
 					or (event.key == pygame.locals.K_s)
-					or (event.key == pygame.locals.K_z)):
+					or (event.key == pygame.locals.K_e)
+					or (event.key == pygame.locals.K_c)):
 						if config.players == 2:
 							self.purpleMan.MoveKeyUp(event.key)
 				elif event.type == greenManSprite.SUPER_STATE_OVER:
@@ -224,15 +212,15 @@ class nomMain(object):
 			if pygame.font:
 				font = pygame.font.Font(None, 36)
 				if config.players == 2:
-					if levelselect == 100:
+					if config.levelselect == 100:
 						text = font.render("Continue?", 1, (255, 255, 255))
 					else:
-						text = font.render("Green %s		Lives %s		  Level %s		   Purple %s " % (self.greenMan.pellets, config.deathCount, levelselect, self.purpleMan.pellets), 1, (255, 255, 255))
+						text = font.render("Green %s		Lives %s		  Level %s		   Purple %s " % (self.greenMan.pellets, config.deathCount, config.levelselect, self.purpleMan.pellets), 1, (255, 255, 255))
 				else:
-					if levelselect == 100:
+					if config.levelselect == 100:
 						text = font.render("Continue?", 1, (255, 255, 255))
 					else:
-						text = font.render("Pellets %s	  Lives %s	   Level %s" % (self.greenMan.pellets, config.deathCount, levelselect), 1, (255, 255, 255))
+						text = font.render("Pellets %s	  Lives %s	   Level %s" % (self.greenMan.pellets, config.deathCount, config.levelselect), 1, (255, 255, 255))
 				textpos = text.get_rect(centerx=self.background.get_width()/2)
 				self.screen.blit(text, textpos)
 				#pnumber = str(self.greenMan.pellets)
@@ -378,7 +366,7 @@ class nomMain(object):
 			screen.blit(background, (0, 0))
 			pygame.display.flip()
 			pygame.time.wait(5000)
-		if levelselect == 16:
+		if config.levelselect == 16:
 			pygame.time.wait(5000)
 			text = font.render("CONGRATULATIONS!", 1, (255, 255, 255))
 			textpos = text.get_rect()
@@ -393,11 +381,11 @@ class nomMain(object):
 		pygame.quit()
 
 	def LoadSprites(self):
-		global levelselect
+		config.areMonstersEvil = False
 		self.total = 0
 		x_offset = (BLOCK_SIZE/2)
 		y_offset = (BLOCK_SIZE/2)
-		self.level1 = levelloader.LevelLoader(DATA_FOLDER, os.path.join(DATA_FOLDER, "levels/level%03d.json" % (levelselect, )))
+		self.level1 = levelloader.LevelLoader(DATA_FOLDER, os.path.join(DATA_FOLDER, "levels/level%03d.json" % (config.levelselect, )))
 		layout = self.level1.getLayout()
 		img_list = self.level1.sprites
 		self.pellet_sprites = pygame.sprite.RenderUpdates()
@@ -441,14 +429,6 @@ class MyForm(QtGui.QMainWindow):
 		QtGui.QMainWindow.__init__(self, parent)
 		self.ui = omnomgui.Ui_GUI()
 		self.ui.setupUi(self)
-		#global gameMusic
-		#global gameSound
-		#global player_speed
-		#global enemy_speed
-		#gameMusic = 1
-		#gameSound = 1
-		#player_speed = 8
-		#enemy_speed = 3
 		self.setWindowTitle("OmNomNom")
 		lvl1 = QtGui.QPixmap(os.path.join(DATA_FOLDER, "images/lvl1.png"))
 		lvl2 = QtGui.QPixmap(os.path.join(DATA_FOLDER, "images/lvl2.png"))
@@ -466,8 +446,7 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.configButton, QtCore.SIGNAL('clicked()'), self.doConfig)
 
 	def doLvl1(self):
-		global levelselect
-		levelselect = 1
+		config.levelselect = 1
 		try:
 			nomMain().MainLoop()
 		except:
@@ -475,8 +454,7 @@ class MyForm(QtGui.QMainWindow):
 			raise
 
 	def doLvl2(self):
-		global levelselect
-		levelselect = 6
+		config.levelselect = 6
 		try:
 			nomMain().MainLoop()
 		except:
@@ -484,8 +462,7 @@ class MyForm(QtGui.QMainWindow):
 			raise
 
 	def doLvl3(self):
-		global levelselect
-		levelselect = 10
+		config.levelselect = 10
 		try:
 			nomMain().MainLoop()
 		except:
@@ -493,8 +470,7 @@ class MyForm(QtGui.QMainWindow):
 			raise
 
 	def doLvl4(self):
-		global levelselect
-		levelselect = 14
+		config.levelselect = 14
 		try:
 			nomMain().MainLoop()
 		except:
@@ -517,18 +493,13 @@ class setConfig(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.applyButton, QtCore.SIGNAL('clicked()'), self.doApply)
 
 	def doApply(self):
-		#global gameMusic
-		#global gameSound
-		#global player_speed
-		#global enemy_speed
-		config.gameMusic = 0
-		config.gameSound = 0
+		config.gameMusic = False
+		config.gameSound = False
 		config.players = 1
-		config.mariomode = 1
 		if self.ui.musicBox.isChecked() == True:
-			config.gameMusic = 1
+			config.gameMusic = True
 		if self.ui.soundBox.isChecked() == True:
-			config.gameSound = 1
+			config.gameSound = True
 		if self.ui.multiBox.isChecked() == True:
 			config.players = 2
 		config.player_speed = self.ui.playerSpeed.value()
